# Import system modules and arcpy
import os
import arcpy
import numpy
from arcpy.sa import *

# Input parameters
# 1: input workspace
# 2: input raster (factor 1)
# 3: input shapefile (landslides)
sourceFolder = arcpy.GetParameterAsText(0)
inRAS = arcpy.GetParameterAsText(1)
inSHP = arcpy.GetParameterAsText(2)
outRAS = arcpy.GetParameterAsText(3)

# Set the workspace
arcpy.env.workspace = sourceFolder

# Create the GDB
geodatabaseName = "SusceptibilityIndex.gdb"
arcpy.CreateFileGDB_management(sourceFolder, geodatabaseName)

# Copy landslides to geodatabase
arcpy.CopyFeatures_management(inSHP, "SusceptibilityIndex.gdb\\inSHP")
arcpy.CopyRaster_management(inRAS, "SusceptibilityIndex.gdb\\inRAS")

# Add fields to inRAS table
arcpy.AddField_management("SusceptibilityIndex.gdb\\inRAS", "At", "FLOAT")
arcpy.AddField_management("SusceptibilityIndex.gdb\\inRAS", "Nt", "LONG")

# Get total pixels in raster (At)
At = 0
with arcpy.da.SearchCursor(inRAS, "Count") as cursor:
	for row in cursor:
		At = At + row[0]

# Get total landslides
Nt = arcpy.GetCount_management(inSHP)

# Assign At and Nt to class fields in inRAS
arcpy.CalculateField_management("SusceptibilityIndex.gdb\\inRAS", "At", "{}".format(At))
arcpy.CalculateField_management("SusceptibilityIndex.gdb\\inRAS", "Nt", "{}".format(Nt))

# Extract multi values to points
ExtractValuesToPoints("SusceptibilityIndex.gdb\\inSHP", "SusceptibilityIndex.gdb\\inRAS", "SusceptibilityIndex.gdb\\CLASS", "NONE", "VALUE_ONLY")

# Get frequency (Nc)
arcpy.Frequency_analysis("SusceptibilityIndex.gdb\\CLASS", "SusceptibilityIndex.gdb\\CLASS_FR", "RASTERVALU") 

# Join frequency table to raster table
arcpy.JoinField_management("SusceptibilityIndex.gdb\\inRAS", "Value", "SusceptibilityIndex.gdb\\CLASS_FR", "RASTERVALU")

# Calculate LSI after adding a field. Note, value is times 1000 because of float/int issues
arcpy.AddField_management("SusceptibilityIndex.gdb\\inRAS", "LSI", "FLOAT")
LSI = "int(math.log((!Frequency!/!Count!)/(!Nt!/!At!))*1000)"
arcpy.CalculateField_management("SusceptibilityIndex.gdb\\inRAS", "LSI", LSI, "PYTHON")

# Run LookUp, Int (for raster table output), and export new raster generating raster catalog
outRaster = Lookup("SusceptibilityIndex.gdb\\inRAS", "LSI")
outRaster.save("TEMP1.tif")
outInt = Int("TEMP1.tif")
outName = "{0}.{1}".format(outRAS, "tif")
outInt.save(outName)
arcpy.Delete_management("TEMP1.tif")
arcpy.Delete_management("SusceptibilityIndex.gdb")